@@ -636,8 +636,8 @@ Ttk_LayoutTemplate Ttk_ParseLayoutTemplate(Tcl_Interp *interp, Tcl_Obj *objPtr)
 	    if (optName[0] != '-')
 		break;
 
-	    if (Tcl_GetIndexFromObj(
-		    interp, objv[i], optStrings, "option", 0, &option)
+	    if (Tcl_GetIndexFromObjStruct(interp, objv[i], optStrings,
+		    sizeof(char *), "option", 0, &option)
 		!= TCL_OK)
 	    {
 		goto error;
@@ -653,8 +653,8 @@ Ttk_LayoutTemplate Ttk_ParseLayoutTemplate(Tcl_Interp *interp, Tcl_Obj *objPtr)
 
 	    switch (option) {
 		case OP_SIDE:	/* <<NOTE-PACKSIDE>> */
-		    if (Tcl_GetIndexFromObj(interp, objv[i], packSideStrings,
-				"side", 0, &value) != TCL_OK)
+		    if (Tcl_GetIndexFromObjStruct(interp, objv[i], packSideStrings,
+				sizeof(char *), "side", 0, &value) != TCL_OK)
 		    {
 			goto error;
 		    }
@@ -702,6 +702,8 @@ Ttk_LayoutTemplate Ttk_ParseLayoutTemplate(Tcl_Interp *interp, Tcl_Obj *objPtr)
 	if (childSpec) {
 	    tail->child = Ttk_ParseLayoutTemplate(interp, childSpec);
 	    if (!tail->child) {
+                Tcl_SetObjResult(interp, Tcl_ObjPrintf("Invalid -children value"));
+                Tcl_SetErrorCode(interp, "TTK", "VALUE", "CHILDREN", NULL);
 		goto error;
 	    }
 	}
